@@ -73,6 +73,7 @@ struct __fehoptions {
 	unsigned char image_bg;
 	unsigned char no_fehbg;
 	unsigned char keep_zoom_vp;
+	unsigned char insecure_ssl;
 
 	char *output_file;
 	char *output_dir;
@@ -82,6 +83,7 @@ struct __fehoptions {
 	char *title;
 	char *thumb_title;
 	char *actions[10];
+	char *action_titles[10];
 	char *fontpath;
 	char *filelistfile;
 	char *menu_font;
@@ -151,6 +153,8 @@ struct __fehkb {
 	struct __fehkey jump_back;
 	struct __fehkey quit;
 	struct __fehkey jump_fwd;
+	struct __fehkey prev_dir;
+	struct __fehkey next_dir;
 	struct __fehkey remove;
 	struct __fehkey delete;
 	struct __fehkey jump_first;
